pub struct Metro {
pub kind: Option<String>,
pub country_dart_id: Option<String>,
pub name: Option<String>,
pub country_code: Option<String>,
pub metro_code: Option<String>,
pub dart_id: Option<String>,
pub dma_id: Option<String>,
}Expand description
Contains information about a metro region that can be targeted by ads.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list metros (none)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#metro”.
country_dart_id: Option<String>DART ID of the country to which this metro region belongs.
name: Option<String>Name of this metro region.
country_code: Option<String>Country code of the country to which this metro region belongs.
metro_code: Option<String>Metro code of this metro region. This is equivalent to dma_id.
dart_id: Option<String>DART ID of this metro region.
dma_id: Option<String>DMA ID of this metro region. This is the ID used for targeting and generating reports, and is equivalent to metro_code.